starsaiot_monit
===============================

version number: 1.0.0
author: wangning

Overview
--------

监控平台

Installation / Usage
--------------------

To install use pip:

    $ pip install starsaiot_monit


Or clone the repo:

    $ git clone https://github.com/huamoai/starsaiot_monit.git
    $ python setup.py install
    
Contributing
------------

TBD

Example
-------

TBD